aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/config
diff options
context:
space:
mode:
authorGravatar tomhudson@google.com <tomhudson@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2011-07-01 17:08:26 +0000
committerGravatar tomhudson@google.com <tomhudson@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2011-07-01 17:08:26 +0000
commit0c8d93a94099dee2dff8da6000ded9ad59676488 (patch)
tree93d68d568132740aef280b4badcf5edb90ce8b7f /include/config
parent9ae4429f9d3ab837ff9352261271974715cabb8a (diff)
Reworks r1770 so that users who have replaced SkUserConfig don't have to
make any changes to continue compiling successfully. git-svn-id: http://skia.googlecode.com/svn/trunk@1779 2bbb7eff-a529-9590-31e7-b0007b416f81
Diffstat (limited to 'include/config')
-rw-r--r--include/config/SkUserConfig.h10
-rw-r--r--include/config/SkUserTrace.h42
2 files changed, 5 insertions, 47 deletions
diff --git a/include/config/SkUserTrace.h b/include/config/SkUserTrace.h
deleted file mode 100644
index c5d168a501..0000000000
--- a/include/config/SkUserTrace.h
+++ /dev/null
@@ -1,42 +0,0 @@
-/*
- Copyright 2010 Google Inc.
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at
-
- http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
- */
-#ifndef SkUserTrace_DEFINED
-#define SkUserTrace_DEFINED
-
-/* If your system embeds skia and has complex event logging, define these
- to map to your system's equivalents. A trivial example is given in
- src/utils/SkDebugTrace.h.
-
- All arguments are const char*. Skia typically passes the name of
- the object and function (and sometimes region of interest within
- the function) separated by double colons for 'event'.
-
- SK_TRACE_EVENT1 and SK_TRACE_EVENT2 take one or two arbitrary
- name-value pairs that you also want to log. SkStringPrintf() is useful
- for formatting these values.
-
- For example:
- SK_TRACE_EVENT0("GrContext::createAndLockTexture");
- SK_TRACE_EVENT1("GrDefaultPathRenderer::onDrawPath::renderPasses",
- "verts", SkStringPrintf("%i", vert - base).c_str());
-*/
-#define SK_TRACE_EVENT0(event)
-#define SK_TRACE_EVENT1(event, name1, value1)
-#define SK_TRACE_EVENT2(event, name1, value1, name2, value2)
-
-#endif
-
-
diff --git a/include/config/SkUserConfig.h b/include/config/SkUserConfig.h
index 6ee514646b..48f6379a03 100644
--- a/include/config/SkUserConfig.h
+++ b/include/config/SkUserConfig.h
@@ -148,17 +148,17 @@
//#define SK_SUPPORT_UNITTEST
#endif
-/* If your system embeds skia and has complex event logging, redefine this
- symbol to point to a file that maps the following macros to your system's
+/* If your system embeds skia and has complex event logging, define this
+ symbol to name a file that maps the following macros to your system's
equivalents:
SK_TRACE_EVENT0(event)
SK_TRACE_EVENT1(event, name1, value1)
SK_TRACE_EVENT2(event, name1, value1, name2, value2)
- include/config/SkUserTrace.h has a no-op implementation, while
src/utils/SkDebugTrace.h has a trivial implementation that writes to
- the debug output stream.
+ the debug output stream. If SK_USER_TRACE_INCLUDE_FILE is not defined,
+ SkTrace.h will define the above three macros to do nothing.
*/
-#define SK_USER_TRACE_INCLUDE_FILE "../../include/config/SkUserTrace.h"
+//#undef SK_USER_TRACE_INCLUDE_FILE
/* Change the ordering to work in X windows.
*/